pub fn from_slice<'a, T>(s: &'a [u8]) -> Result<T>where
T: Deserialize<'a>,Expand description
Deserialize an instance of type T from a byte slice of SQLite JSONB data.
pub fn from_slice<'a, T>(s: &'a [u8]) -> Result<T>where
T: Deserialize<'a>,Deserialize an instance of type T from a byte slice of SQLite JSONB data.